@@ -12,12 +12,17 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with openreviewio-py.  If not, see <https://www.gnu.org/licenses/>
+
+from dataclasses import dataclass
 from pathlib import Path
 import toml
 from typing import Union
 
+from .base import ReviewItem
 
-class TextComment:
+
+@dataclass
+class TextComment(ReviewItem):
     body: str
 
     def __init__(self, body: str):
@@ -26,21 +31,25 @@ class TextComment:
         :param body: Comment message
         :type body: str
         """
+        super().__init__()
+
         self.body = body
 
 
-class TextAnnotation(TextComment):
+@dataclass
+class TextAnnotation(TextComment, ReviewItem):
     frame: int
     duration: int
 
     def __init__(self, body: str, frame: int, duration: int):
         super().__init__(body)
 
-        self.frame = frame
-        self.duration = duration
+        self.frame = int(frame)
+        self.duration = int(duration)
 
 
-class Image:
+@dataclass
+class Image(ReviewItem):
 
     __mime__ = {"jpeg", "jpg", "png"}
     path_to_image: Union[Path, str]
@@ -50,6 +59,8 @@ class Image:
 
         :param path_to_image: Path to image file
         """
+        super().__init__()
+
         self.path_to_image = Path(path_to_image)
 
         # Check mime for file extension
@@ -62,9 +73,11 @@ class Image:
                 )
 
 
-class ImageAnnotation(Image):
+@dataclass
+class ImageAnnotation(Image, ReviewItem):
     frame: int
     duration: int
+    _reference_image = None
     reference_image: Union[Path, str, Image]
 
     def __init__(
@@ -85,8 +98,8 @@ class ImageAnnotation(Image):
         """
         super(ImageAnnotation, self).__init__(path_to_image)
 
-        self.frame = frame
-        self.duration = duration
+        self.frame = int(frame)
+        self.duration = int(duration)
 
         self.reference_image = reference_image
 
