@@ -15,7 +15,9 @@
 
 from __future__ import annotations
 
+from dataclasses import dataclass
 from datetime import datetime
+from .base import ReviewItem
 import operator
 from pathlib import Path
 import shutil
@@ -26,13 +28,19 @@ from .Note import Note
 from . import logging
 
 import lxml.etree as ET
-from inspect import getmembers
+from inspect import getmembers, isroutine
 
 
-class MediaReview:
+@dataclass
+class MediaReview(ReviewItem):
 
-    _media: Path
-    _status_history: List[Status] = []  # Read only
+    _media = None
+    media: Union[str, Path]
+    _status = None
+    status: Status = None
+    notes: List[Note] = None
+    metadata: dict = None
+    _status_history = []  # Read only
 
     def __init__(
         self,
@@ -48,6 +56,8 @@ class MediaReview:
         :param notes: Review's notes ordered by creation date. TODO Read only ?
         :param metadata: Review's metadata.
         """
+        super().__init__()
+
         self.media = media
 
         self.status = status or Status("waiting review", "default")
@@ -67,6 +77,17 @@ class MediaReview:
     def media(self, value):
         self._media = Path(value)
 
+    # Status getter and setter
+    @property
+    def status(self):
+        return self._status
+
+    @status.setter
+    def status(self, value):
+        if type(value) is not Status:
+            value = Status(value)
+        self._status = value
+
     def add_note(self, note: Union[Note, List[Note]] = None):
         """Append a note (or all notes if a list is provided) it to the review's notes list.
 
@@ -81,7 +102,7 @@ class MediaReview:
                 self.notes.append(note)
             else:
                 warnings.warn(
-                    f"Note with date: {note.date} already exists, not overrided. Use get_note() to modify it.",
+                    f"Note with date: {note.date} already exists, not overridden. Use get_note() to modify it.",
                     Warning,
                     stacklevel=2,
                 )
@@ -136,6 +157,24 @@ class MediaReview:
                 if n.date == datetime.fromisoformat(date):
                     return n
 
+    def get_notes_list(self, from_date: datetime = None) -> List[Note]:
+        """Get notes depending on some filtering parameters.
+
+        :param from_date: Date to get notes from, defaults to None
+        :return: List of filtered notes
+        """
+        notes_list = []
+
+        # Return all if from_date is None
+        if not from_date:
+            return self.notes
+
+        for note in self.notes:
+            if note.date > from_date:
+                notes_list.append(note)
+
+        return notes_list
+
     def write(
         self, path: Union[str, Path] = "", include_attached_files: bool = True
     ) -> Path:
@@ -214,7 +253,7 @@ class MediaReview:
             for c in n.contents:
                 # Dynamically set parameters from members
                 params = {}
-                for attribute, value in getmembers(c):
+                for attribute, value in getmembers(c, lambda a: not (isroutine(a))):
                     if not attribute.startswith("_"):
                         if (
                             attribute in {"path_to_image", "reference_image"}
